contexttools.detach_staff_change_marks_attached_to_component
============================================================

.. autofunction:: abjad.tools.contexttools.detach_staff_change_marks_attached_to_component.detach_staff_change_marks_attached_to_component
